==> owncloud-4.0.4.tgz: owncloud/core/l10n/et_EE.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Rakenduse nime pole sisestatud.",
"No category to add?" => "Pole kategooriat, mida lisada?",
"This category already exists: " => "See kategooria on juba olemas: ",
"Owncloud password reset" => "Owncloud parooli taastamine",
"ownCloud password reset" => "ownCloud parooli taastamine",
"Use the following link to reset your password: {link}" => "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
"You will receive a link to reset your password via Email." => "Sinu parooli taastamise link saadetakse sulle e-postile.",
"Requested" => "Kohustuslik",
"Login failed!" => "Sisselogimine ebaõnnestus!",
"Username" => "Kasutajanimi",
"Request reset" => "Päringu taastamine",
"Your password was reset" => "Sinu parool on taastatud",
"To login page" => "Sisselogimise lehele",
"New password" => "Uus parool",
"Reset password" => "Nulli parool",
"Personal" => "isiklik",
"Users" => "Kasutajad",
"Apps" => "Programmid",
"Admin" => "Admin",
"Help" => "Abiinfo",
"Access forbidden" => "Ligipääs on keelatud",
"Cloud not found" => "Pilve ei leitud",
"Edit categories" => "Muuda kategooriaid",
"Add" => "Lisa",
"Create an <strong>admin account</strong>" => "Loo <strong>admini konto</strong>",
"Password" => "Parool",
"Advanced" => "Lisavalikud",
"Data folder" => "Andmete kaust",
"Configure the database" => "Seadista andmebaasi",
"will be used" => "kasutatakse",
"Database user" => "Andmebaasi kasutaja",
"Database password" => "Andmebaasi parool",
"Database name" => "Andmebasi nimi",
"Database host" => "Andmebaasi host",
"Finish setup" => "Lõpeta seadistamine",
"web services under your control" => "veebiteenused sinu kontrolli all",
"Log out" => "Logi välja",
"Settings" => "Seaded",
"Lost your password?" => "Kaotasid oma parooli?",
"remember" => "pea meeles",
"Log in" => "Logi sisse",
"You are logged out." => "Sa oled välja loginud",
"prev" => "eelm",
"next" => "järgm"
);

==> owncloud-4.5.7.tgz: owncloud/core/l10n/et_EE.php <==
<?php $TRANSLATIONS = array(
"Application name not provided." => "Rakenduse nime pole sisestatud.",
"No category to add?" => "Pole kategooriat, mida lisada?",
"This category already exists: " => "See kategooria on juba olemas: ",
"Settings" => "Seaded",
"January" => "Jaanuar",
"February" => "Veebruar",
"March" => "Märts",
"April" => "Aprill",
"May" => "Mai",
"June" => "Juuni",
"July" => "Juuli",
"August" => "August",
"September" => "September",
"October" => "Oktoober",
"November" => "November",
"December" => "Detsember",
"Cancel" => "Loobu",
"No" => "Ei",
"Yes" => "Jah",
"Ok" => "Ok",
"No categories selected for deletion." => "Kustutamiseks pole kategooriat valitud.",
"Error" => "Viga",
"Password" => "Parool",
"ownCloud password reset" => "ownCloud parooli taastamine",
"Use the following link to reset your password: {link}" => "Kasuta järgnevat linki oma parooli taastamiseks: {link}",
"You will receive a link to reset your password via Email." => "Sinu parooli taastamise link saadetakse sulle e-postile.",
"Requested" => "Kohustuslik",
"Login failed!" => "Sisselogimine ebaõnnestus!",
"Username" => "Kasutajanimi",
"Request reset" => "Päringu taastamine",
"Your password was reset" => "Sinu parool on taastatud",
"To login page" => "Sisselogimise lehele",
"New password" => "Uus parool",
"Reset password" => "Nulli parool",
"Personal" => "isiklik",
"Users" => "Kasutajad",
"Apps" => "Programmid",
"Admin" => "Admin",
"Help" => "Abiinfo",
"Access forbidden" => "Ligipääs on keelatud",
"Cloud not found" => "Pilve ei leitud",
"Edit categories" => "Muuda kategooriaid",
"Add" => "Lisa",
"Create an <strong>admin account</strong>" => "Loo <strong>admini konto</strong>",
"Advanced" => "Lisavalikud",
"Data folder" => "Andmete kaust",
"Configure the database" => "Seadista andmebaasi",
"will be used" => "kasutatakse",
"Database user" => "Andmebaasi kasutaja",
"Database password" => "Andmebaasi parool",
"Database name" => "Andmebasi nimi",
"Database host" => "Andmebaasi host",
"Finish setup" => "Lõpeta seadistamine",
"web services under your control" => "veebiteenused sinu kontrolli all",
"Log out" => "Logi välja",
"Lost your password?" => "Kaotasid oma parooli?",
"remember" => "pea meeles",
"Log in" => "Logi sisse",
"You are logged out." => "Sa oled välja loginud",
"prev" => "eelm",
"next" => "järgm"
);
